---
title: <span class="badge builder"></span> QueryHistoryPreference
---
# <span class="badge builder"></span> QueryHistoryPreference

## Constructor

```python
QueryHistoryPreference()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> preferences.QueryHistoryPreference
```

### <span class="badge object-method"></span> home_tab

one of: '' | 'query' | 'starred';

```python
def home_tab(home_tab: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [QueryHistoryPreference](./object-QueryHistoryPreference.md)
